/*
 * mcu1_pins.c
 *
 * Initialization and Operational code for TIDA-00271, SAT0074
 *
 * Copyright (C) 2014 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/


#ifndef MCU1_PINS_H_
#define MCU1_PINS_H_

//MCU1 (Power)

//PORT 1
#define in_n5V_SW_FAULT_CAM1        P1DIR &= ~BIT0  //output signal 5V switcher n5V_SW_FAULT_CAM1
#define in_n5V_SW_FAULT_CAM2        P1DIR &= ~BIT1  //output signal 5V switcher n5V_SW_FAULT_CAM2
#define in_n5V_SW_FAULT_CAM3        P1DIR &= ~BIT2  //output signal 5V switcher n5V_SW_FAULT_CAM3
#define in_n8V_SW_THM               P1DIR &= ~BIT3  //output signal 8V switcher n8V_SW_THM
#define out_EN_LVLSHIFT1            P1DIR |= BIT4   //input signal I2C levelshifter 1 EN_LVLSHIFT1
#define out_PWR_MCU_DATA_AVAILABLE  P1DIR |= BIT5   //input signal mainboard PWR_MCU_DATA_AVAILABLE
#define out_PWR_MCU_MASTER_SLAVE    P1DIR |= BIT6   //input signal mainboard PWR_MCU_MASTER_SLAVE
#define in_n8V_SW_ERROR             P1DIR &= ~BIT7  //output signal 8V switcher n8V_SW_ERROR


//PORT 2
#define in_INA200_CMPOUT_CAM1       P2DIR &= ~BIT0  //output signal INA200 INA200_CMPOUT_CAM1
#define in_INA200_CMPOUT_CAM2       P2DIR &= ~BIT1  //output signal INA200 INA200_CMPOUT_CAM2
#define in_INA200_CMPOUT_CAM3       P2DIR &= ~BIT2  //output signal INA200 INA200_CMPOUT_CAM2
#define in_PG_5V_1A                 P2DIR &= ~BIT3  //output signal 5V 1A buck PG_5V_1A
#define in_PG_3V3                   P2DIR &= ~BIT4  //output signal 3V3 buck PG_3V3
#define in_MCU1_2_WAKE_UP_SLEEP     P2DIR &= ~BIT5  //output signal mainboard MCU1+2_WAKE_UP+SLEEP
#define out_nINA200_RESET_CAM1      P2DIR |= BIT6   //input signal INA200 out_nINA200_RESET_CAM1
#define in_PG_5V_2A5                P2DIR &= ~BIT7  //output signal 3V3 buck PG_3V3


//PORT 3
#define out_8V_SW_CLK               P3DIR |= BIT0   //input signal 8V switcher 8V_SW_CLK
#define in_I2C5_SDA                 P3DIR &= ~BIT1  //as input defined for testing
#define in_I2C5_SCL                 P3DIR &= ~BIT2  //as input defined for testing
#define out_n8V_SW_CS               P3DIR |= BIT3   //input signal 8V switcher n8V_SW_CS
#define out_8V_SW_EN                P3DIR |= BIT4   //input signal 8V switcher n8V_SW_EN
#define in_8V_SW_DATAOUT            P3DIR &= ~BIT5  //output signal 8V switcher 8V_SW_DATAOUT
#define out_8V_OR_n5V_SW_CAM1       P3DIR |= BIT6   //input signal 8V and 5V switcher 8V_OR_n5V_SW_CAM1
#define out_8V_OR_n5V_SW_CAM2       P3DIR |= BIT7   //input signal 8V and 5V switcher 8V_OR_n5V_SW_CAM2


//PORT 4
#define out_nINA200_RESET_CAM3      P4DIR |= BIT0   //input signal INA200 out_nINA200_RESET_CAM3
#define out_EN_5V_2A5               P4DIR |= BIT1   //input signal 5V 2A5 buck EN_5V_2A5
#define out_EN_5V_1A                P4DIR |= BIT2   //input signal 5V 1A buck EN_5V_1A
#define out_nINA200_RESET_CAM2      P4DIR |= BIT3   //input signal INA200 out_nINA200_RESET_CAM2
#define out_EN_8V                   P4DIR |= BIT4   //input signal 8V switcher EN_8V
#define out_EN_1V8                  P4DIR |= BIT5   //input signal 1V8 buck EN_1V8
#define out_926_CONFIG_READY        P4DIR |= BIT6   //input signal CPLD 926_CONFIG_READY
#define out_8V_OR_n5V_SW_CAM3       P4DIR |= BIT7   //input signal 8V and 5V switcher 8V_OR_n5V_SW_CAM3


#endif /* MCU1_PINS_H_ */
